@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: AttachSettings.py 10804 2018-03-02 03:53:42Z David $
+# $Id: AttachSettings.py 10827 2018-03-11 15:11:03Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2018-03-02 11:53:42 +0800 (Fri, 02 Mar 2018) $
-# $Revision: 10804 $
+# $Date: 2018-03-11 23:11:03 +0800 (Sun, 11 Mar 2018) $
+# $Revision: 10827 $
 
 import os
 
@@ -55,18 +55,21 @@ def attachSettings(settingsDict):
             'admin_reorder',  
             
             'emencia.django.newsletter',
-            # newsletter_extension uses cloud app to resend error newsletters.
-            'Theophrastus.cloud',
+            
+            'Theophrastus.api',
             'Theophrastus.newsletter_extension',
             'Theophrastus.editor',
             'Theophrastus.statistics',
-            'Theophrastus.document',  
-            
+
+            'Theophrastus.document',
+             # Mailer in cloud app need Header, Footer in newsletter_extension
+             # to send newsletters.
+            'Theophrastus.cloud',
         ])
-        
+        # integration and api app depends on  statistics app
         if settingsDict.get('THEOPHRASTUS_ENABLE_INTEGRATION', False):
             installedApps.append('Theophrastus.integration')
-            installedApps.append('Theophrastus.api')
+            
 
         index = installed.index('Theophrastus')
         startApps = list(installed[:index])
