@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Mailer.py 10850 2018-03-17 23:41:09Z David $
+# $Id: Mailer.py 11004 2018-05-01 01:15:42Z Kevin $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,20 +11,25 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $ (Last)
+# $Author: Kevin $ (Last)
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 10850 $
+# $Revision: 11004 $
 
 import os
+import re
 import random
 import mimetypes
 import time
 import threading
 
+from StringIO import StringIO
 from datetime import datetime
 from smtplib import SMTPRecipientsRefused
 
-from django.core.mail import EmailMessage
+from email.mime.multipart import MIMEMultipart
+from email.mime.text import MIMEText
+
+from django.core.mail import EmailMessage, EmailMultiAlternatives
 from django.utils.encoding import smart_str, smart_unicode
 from django.contrib.sites.models import Site
 from django.template import Context
@@ -47,6 +52,7 @@ from Iuno.cloud.mail import EmailBackend
 from Iuno.cloud.mail import SendMessageException, RetryAndSendException
 
 from emencia.django.newsletter.models import ContactMailingStatus, Newsletter
+from html2text import html2text as html2text_orig
 
 from Theophrastus.cloud.models import ErrorMessage
 from Theophrastus.cloud.service import CloudService
@@ -56,6 +62,23 @@ from Theophrastus.newsletter_extension.views import getHeaderContent, \
 
 cloudSrv = CloudService.getInstance()
 
+LINK_RE = re.compile(r"https?://([^ \n]+\n)+[^ \n]+", re.MULTILINE)
+
+def html2text(html):
+    """Use html2text but repair newlines cutting urls.
+    Need to use this hack until
+    https://github.com/aaronsw/html2text/issues/#issue/7 is not fixed"""
+    txt = html2text_orig(html)
+    links = list(LINK_RE.finditer(txt))
+    out = StringIO()
+    pos = 0
+    for l in links:
+        out.write(txt[pos:l.start()])
+        out.write(l.group().replace('\n', ''))
+        pos = l.end()
+    out.write(txt[pos:])
+    return out.getvalue()
+
 class CloudSMTP(object):
     def __init__(self, newsletter, test=False, fakeTest=False):
         """
@@ -82,16 +105,20 @@ class CloudSMTP(object):
         mail = None
         try:
             backend = EmailBackend(fallback=False)
-            mail = EmailMessage(
-                subject, content, from_email=fromEmail, to=[contact.email],
-                connection=backend,
-                headers={'Reply-To': replyTo})
+            
+            contentHtml = content
+            contentText = html2text(contentHtml)
+
+            mail = EmailMultiAlternatives(
+                subject, contentText, from_email=fromEmail, to=[contact.email],
+                connection=backend, headers={'Reply-To': replyTo})
+            mail.attach_alternative(contentHtml, "text/html")
 
             if attachments:
                 for (title, c, maintype) in attachments:
                     mail.attach(utf8(title), c, maintype)
 
-            mail.content_subtype = "html"
+            mail.content_subtype = "mixed"
             if self.fakeTest:
                 time.sleep(3)
             else:
@@ -298,8 +325,9 @@ class CloudMailer(Mailer):
             elif self.useCloud:
                 subject = self.build_title_content(contact)
                 replyTo = smart_str(self.newsletter.header_reply)
+
                 contentHtml = self.buildEmailContent(contact)
-                
+
                 result = self.smtp.sendMail(
                     contact,
                     subject,
