@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 10803 2018-03-02 03:45:30Z David $
+# $Id: admin.py 10891 2018-03-19 08:43:22Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2018-03-02 11:45:30 +0800 (Fri, 02 Mar 2018) $
-# $Revision: 10803 $
+# $Date: 2018-03-19 16:43:22 +0800 (Mon, 19 Mar 2018) $
+# $Revision: 10891 $
 
 from django import forms
 from django.contrib import admin
@@ -27,6 +27,9 @@ from emencia.django.newsletter.models import Newsletter
 from Theophrastus.newsletter_extension.admin import NewsletterExtensionAdmin \
                                                     as NewsletterAdmin
 from Theophrastus.newsletter_extension.admin import NewsletterForm
+from Theophrastus.newsletter_extension.models import Header, Footer
+from Theophrastus.editor.forms import HeaderTinyMCEForm
+from Theophrastus.editor.forms import FooterTinyMCEForm
 from TinyMCEWidget import CustomTinyMCEWidget
 
 class NewsletterTinyMCEForm(NewsletterForm):
@@ -43,3 +46,17 @@ class NewsletterTinyMCEAdmin(NewsletterAdmin):
 admin.site.unregister(Newsletter)
 admin.site.register(Newsletter, NewsletterTinyMCEAdmin)
 
+class HeaderTinyMCEAdmin(admin.ModelAdmin):
+    list_display=['title']
+    form = HeaderTinyMCEForm
+
+admin.site.unregister(Header)
+admin.site.register(Header, HeaderTinyMCEAdmin)
+
+class FooterTinyMCEAdmin(admin.ModelAdmin):
+    list_display=['title']
+    form = FooterTinyMCEForm
+
+admin.site.unregister(Footer)
+admin.site.register(Footer, FooterTinyMCEAdmin)
+
